#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# If you have not received a copy of the GNU General Public License along
# with this program, see <https://www.gnu.org/licenses/>.

# part of mkp package "hbrsrv"
# see package descripton for information

#<<<hbrsrv>>>
#rpo 480
#pauseRpo 0
#snapshotTime 1686029866


# import api
from .agent_based_api.v1 import *

# import item_state
#from cmk.base.item_state import set_item_state, get_item_state


# time, he's waiting in the wings
import time

# factory settings:
hbrsrv_factory_settings = {
    "age_warn"      : ( 10.0, 25.0 ), # +10%/+25%
    "ign_pause"     : False,
}

# parse function
def parse_hbrsrv(string_table):

    data       = {}
    
    # loop thru agent output
    for line in string_table:
        data[line[0]] = ' '.join(line[1:])

    return data


# discovery function
def discover_hbrsrv(section):
    yield Service()


# check function
def check_hbrsrv(params, section):

    # initial  
    mysummary = []
    marker    = ''

    # calculate lag time
    age       = int(time.time()-int(section['snapshotTime']))
    age_hr    = render.timespan(age)
    yield Metric('age', age)

    # check rpo
    rpo       = int(section['rpo'])*60
    rpo_hr    = render.timespan(rpo)

    # beautify
    for what in [' 0 minutes', ' 0 hours']:
        if rpo_hr.endswith(what):
            rpo_hr = rpo_hr[:-len(what)]

    # check pausing
    if section['pauseRpo'] != '0':
        if params['ign_pause'] == False:
            mysummary.append('Replication Not Active(!)')
        else:
            yield Result(state=State.OK, summary='Not Active')
            return
    
    # get threshold and set marker if checking is desired
    warn, crit = params['age_warn']
    if crit > 0:
        warn   = rpo + rpo/100*int(warn)
        crit   = rpo + rpo/100*int(crit)
        marker = '(!!)' if age > crit else '(!)' if age > warn else ''

    mysummary.append('Lag time: %s%s (RPO: %s)' % (age_hr, marker, rpo_hr))

    # get state
    mysummary = ', '.join(mysummary)
    mystate   = State.CRIT if '!!' in mysummary else State.WARN if '!' in mysummary else State.OK

    # this is the end, my friend.
    yield Result(state=mystate, summary=mysummary)
    return

# register parse function
register.agent_section(
    name                = "hbrsrv",
    parse_function      = parse_hbrsrv,
)

# register check
register.check_plugin(
    name                     = "hbrsrv",
    service_name             = "vSphere Replication",
    discovery_function       = discover_hbrsrv,
    check_function           = check_hbrsrv,
    check_ruleset_name       = "hbrsrv",
    check_default_parameters = hbrsrv_factory_settings,
)
