#!/usr/bin/env python3
#
# part of mkp package "hbrsrv"
# see package description for details
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Alternative,
    Integer,
    ListOfStrings,
    Percentage,
    Tuple,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersStorage,
)


def _parameter_valuespec_hbrsrv():
    return Dictionary(
        title    = _("vSphere Replication"),
        help     = _("Check replications RPO."),
        elements = [
            ("age_warn",
                Tuple(
                    title    = _("Allow RPO exceeding"),
                    help     = _("Configured percentage is added to RPO."
                                 " Set CRIT to 0 to disable checking"),
                    elements = [
                        Percentage(
                            title         = _("Warning if RPO exceeded by"),
                            default_value = 10.0
                        ),
                        Percentage(
                            title         = _("Critical if RPO exceeded by"),
                            default_value = 25.0
                        )
                    ]
                )
            ),
            ("ign_pause",
                Checkbox(
                    title       = _("Ignore Pausing"),
                    help        = _("If ignored, no RPO violations will be detected"),
                    default_value = False,
                )
            ),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="hbrsrv",
        group=RulespecGroupCheckParametersStorage,
        parameter_valuespec=_parameter_valuespec_hbrsrv,
        title=lambda: _("vSphere Replication"),
    )
)
